@@ -551,8 +551,8 @@ int print_magic_type( const std::string & magic_type )
   {
   std::string data;
 
-  if( magic_type == "gzip" ) std::printf( "\x1F\x8B" );
-  else if( magic_type == "bzip2" ) std::printf( "BZh" );
+  if( magic_type == "bzip2" ) std::printf( "BZh" );
+  else if( magic_type == "gzip" ) std::printf( "\x1F\x8B" );
   else if( magic_type == "lzip" ) std::printf( "LZIP" );
   else if( magic_type == "xz" ) std::printf( "%c7zXZ", '\xFD' );
   else if( hex_to_data( magic_type, data ) ) std::printf( data.c_str() );
